@@ -3,17 +3,21 @@
 
 import pydantic
 
-from ..base import DyffSchemaBaseModel, Int64
+from ..base import DyffSchemaBaseModel
 
 
 class TaggedSpan(DyffSchemaBaseModel):
     """A contiguous subsequence of text with a corresponding tag."""
 
-    start: Int64 = pydantic.Field(
-        description="The index of the first character in the span"
+    start: int = pydantic.Field(
+        description="The index of the first character in the span",
+        ge=0,  # Text indices should be non-negative
+        json_schema_extra={"dyff.io/dtype": "int64"},
     )
-    end: Int64 = pydantic.Field(
-        description="The index one past the final character in the span"
+    end: int = pydantic.Field(
+        description="The index one past the final character in the span",
+        ge=0,  # Text indices should be non-negative
+        json_schema_extra={"dyff.io/dtype": "int64"},
     )
     tag: str = pydantic.Field(description="The tag of the span")
 
